@@ -170,7 +170,7 @@ export default function getMenu (
         },
         {
           id: 'menu.previous_file',
-          label: 'Previous file',
+          label: trans('menu.previous_file'),
           accelerator: 'Ctrl+[',
           click: function (menuitem, focusedWindow) {
             commands.run('previous-file', undefined)
@@ -181,7 +181,7 @@ export default function getMenu (
         },
         {
           id: 'menu.next_file',
-          label: 'Next file',
+          label: trans('menu.next_file'),
           accelerator: 'Ctrl+]',
           click: function (menuitem, focusedWindow) {
             commands.run('next-file', undefined)
