@@ -20,10 +20,9 @@ import { v4 as uuid } from 'uuid'
  * Generates a new filename based on the configured filename pattern.
  * @return {string} The new filename.
  */
-export default function generateFilename (): string {
-  let pattern = global.config.get('newFileNamePattern')
-  pattern = replaceStringVariables(pattern)
-  pattern = pattern.replace(/%id/g, generateId(global.config.get('zkn.idGen')))
+export default function generateFilename (filenamePattern: string, idGenPattern: string): string {
+  let pattern = replaceStringVariables(filenamePattern)
+  pattern = pattern.replace(/%id/g, generateId(idGenPattern))
   // In case a funny guy has removed the pattern from config.
   if (pattern.trim().length === 0) {
     pattern = uuid()
