@@ -57,6 +57,11 @@ export default function (): any {
           type: 'checkbox',
           label: trans('dialog.preferences.display.render_htags'),
           model: 'display.renderHTags'
+        },
+        {
+          type: 'checkbox',
+          label: trans('dialog.preferences.display.render_emphasis'),
+          model: 'display.renderEmphasis'
         }
       ],
       [
